@@ -132,34 +132,34 @@ class Lrange:
 		self._core.io.write_struct('CONFigure:BLUetooth:MEASurement<Instance>:MEValuation:LIMit:LENergy:LRANge:FACCuracy', value)
 
 	# noinspection PyTypeChecker
-	class FreqOffsetStruct(StructBase):
+	class FoffsetStruct(StructBase):
 		"""Structure for reading output parameters. Fields: \n
 			- Freq_Offset: float: numeric Range: 0 Hz to 250 kHz
-			- Freq_Offset_Enab: List[bool]: OFF | ON Disable or enable limit checking for current, average, and maximum results (3 values)"""
+			- Freq_Offset_Enable: List[bool]: OFF | ON Disable or enable limit checking for current, average, and maximum results (3 values)"""
 		__meta_args_list = [
 			ArgStruct.scalar_float('Freq_Offset'),
-			ArgStruct('Freq_Offset_Enab', DataType.BooleanList, None, False, False, 3)]
+			ArgStruct('Freq_Offset_Enable', DataType.BooleanList, None, False, False, 3)]
 
 		def __init__(self):
 			StructBase.__init__(self, self)
 			self.Freq_Offset: float = None
-			self.Freq_Offset_Enab: List[bool] = None
+			self.Freq_Offset_Enable: List[bool] = None
 
-	def get_freq_offset(self) -> FreqOffsetStruct:
+	def get_foffset(self) -> FoffsetStruct:
 		"""SCPI: CONFigure:BLUetooth:MEASurement<Instance>:MEValuation:LIMit:LENergy:LRANge:FOFFset \n
-		Snippet: value: FreqOffsetStruct = driver.configure.multiEval.limit.lowEnergy.lrange.get_freq_offset() \n
+		Snippet: value: FoffsetStruct = driver.configure.multiEval.limit.lowEnergy.lrange.get_foffset() \n
 		Sets/gets the frequency offset limit. Commands for uncoded LE 1M PHY (..:LE1M..) , LE 2M PHY (..:LE2M..) , and LE coded
 		PHY (..:LRANge..) are available. \n
-			:return: structure: for return value, see the help for FreqOffsetStruct structure arguments.
+			:return: structure: for return value, see the help for FoffsetStruct structure arguments.
 		"""
-		return self._core.io.query_struct('CONFigure:BLUetooth:MEASurement<Instance>:MEValuation:LIMit:LENergy:LRANge:FOFFset?', self.__class__.FreqOffsetStruct())
+		return self._core.io.query_struct('CONFigure:BLUetooth:MEASurement<Instance>:MEValuation:LIMit:LENergy:LRANge:FOFFset?', self.__class__.FoffsetStruct())
 
-	def set_freq_offset(self, value: FreqOffsetStruct) -> None:
+	def set_foffset(self, value: FoffsetStruct) -> None:
 		"""SCPI: CONFigure:BLUetooth:MEASurement<Instance>:MEValuation:LIMit:LENergy:LRANge:FOFFset \n
-		Snippet: driver.configure.multiEval.limit.lowEnergy.lrange.set_freq_offset(value = FreqOffsetStruct()) \n
+		Snippet: driver.configure.multiEval.limit.lowEnergy.lrange.set_foffset(value = FoffsetStruct()) \n
 		Sets/gets the frequency offset limit. Commands for uncoded LE 1M PHY (..:LE1M..) , LE 2M PHY (..:LE2M..) , and LE coded
 		PHY (..:LRANge..) are available. \n
-			:param value: see the help for FreqOffsetStruct structure arguments.
+			:param value: see the help for FoffsetStruct structure arguments.
 		"""
 		self._core.io.write_struct('CONFigure:BLUetooth:MEASurement<Instance>:MEValuation:LIMit:LENergy:LRANge:FOFFset', value)
 
@@ -167,15 +167,15 @@ class Lrange:
 	class DeltaStruct(StructBase):
 		"""Structure for reading output parameters. Fields: \n
 			- Delta_F_1_P_99_P_9: float: numeric Range: 150 kHz to 250 kHz
-			- Delta_F_1_P_99_Enabl: bool: OFF | ON Disable/enable limit checking"""
+			- Delta_F_1_P_99_Enable: bool: OFF | ON Disable/enable limit checking"""
 		__meta_args_list = [
 			ArgStruct.scalar_float('Delta_F_1_P_99_P_9'),
-			ArgStruct.scalar_bool('Delta_F_1_P_99_Enabl')]
+			ArgStruct.scalar_bool('Delta_F_1_P_99_Enable')]
 
 		def __init__(self):
 			StructBase.__init__(self, self)
 			self.Delta_F_1_P_99_P_9: float = None
-			self.Delta_F_1_P_99_Enabl: bool = None
+			self.Delta_F_1_P_99_Enable: bool = None
 
 	def get_delta(self) -> DeltaStruct:
 		"""SCPI: CONFigure:BLUetooth:MEASurement<Instance>:MEValuation:LIMit:LENergy:LRANge:DELTa \n
