@@ -191,7 +191,7 @@ class Result:
 			- Iq_Differential: bool: OFF | ON IQ constellation differential (only for EDR)
 			- Iq_Error: bool: OFF | ON IQ constellation error (only for EDR)
 			- Freq_Dev: bool: OFF | ON Frequency deviation (only for BR and LE)
-			- Pv_T: bool: OFF | ON Power vs. time
+			- Power_Vs_Time: bool: OFF | ON Power vs. time
 			- Power_Scalars: bool: OFF | ON Statistical power results
 			- Spectrum_Obw: bool: OFF | ON Spectrum 20 dB bandwidth (only for BR)
 			- Spectrum_Acp: bool: OFF | ON Spectrum ACP (only for BR and LE)
@@ -207,7 +207,7 @@ class Result:
 			ArgStruct.scalar_bool('Iq_Differential'),
 			ArgStruct.scalar_bool('Iq_Error'),
 			ArgStruct.scalar_bool('Freq_Dev'),
-			ArgStruct.scalar_bool('Pv_T'),
+			ArgStruct.scalar_bool('Power_Vs_Time'),
 			ArgStruct.scalar_bool('Power_Scalars'),
 			ArgStruct.scalar_bool('Spectrum_Obw'),
 			ArgStruct.scalar_bool('Spectrum_Acp'),
@@ -225,7 +225,7 @@ class Result:
 			self.Iq_Differential: bool = None
 			self.Iq_Error: bool = None
 			self.Freq_Dev: bool = None
-			self.Pv_T: bool = None
+			self.Power_Vs_Time: bool = None
 			self.Power_Scalars: bool = None
 			self.Spectrum_Obw: bool = None
 			self.Spectrum_Acp: bool = None
