@@ -11,12 +11,12 @@ class Sense:
 		self._base = CommandsGroup("sense", core, parent)
 
 	@property
-	def eventLogging(self):
-		"""eventLogging commands group. 0 Sub-classes, 2 commands."""
-		if not hasattr(self, '_eventLogging'):
-			from .Sense_.EventLogging import EventLogging
-			self._eventLogging = EventLogging(self._core, self._base)
-		return self._eventLogging
+	def elogging(self):
+		"""elogging commands group. 0 Sub-classes, 2 commands."""
+		if not hasattr(self, '_elogging'):
+			from .Sense_.Elogging import Elogging
+			self._elogging = Elogging(self._core, self._base)
+		return self._elogging
 
 	def clone(self) -> 'Sense':
 		"""Clones the group by creating new object from it and its whole existing sub-groups
