@@ -17,7 +17,7 @@ class Catalog:
 		"""SCPI: TRIGger:BLUetooth:MEASurement<Instance>:MEValuation:CATalog:SOURce \n
 		Snippet: value: List[str] = driver.trigger.multiEval.catalog.get_source() \n
 		Lists all trigger source values that can be set using method RsCmwBluetoothMeas.Trigger.MultiEval.source. \n
-			:return: sourcelist: string Comma-separated list of all supported values. Each value is represented as a string.
+			:return: source_list: string Comma-separated list of all supported values. Each value is represented as a string.
 		"""
 		response = self._core.io.query_str('TRIGger:BLUetooth:MEASurement<Instance>:MEValuation:CATalog:SOURce?')
 		return Conversions.str_to_str_list(response)
